@@ -294,6 +294,26 @@ on(Src s, Dest d) {
   return on_t<Src, Dest>(s, d);
 }  
 
+template <typename Src, typename Dest>
+struct on2_t : public std::binary_function<typename Src::argument_type, typename Dest::second_argument_type, typename Dest::result_type> {
+  typedef typename Dest::result_type result_type;
+
+  on2_t(Src s, Dest d) : m_dest(d), m_src(s) {}
+
+  result_type operator () (typename reference_fix<typename Src::argument_type>::type first, typename reference_fix<typename Dest::second_argument_type>::type second) {
+    return m_dest(m_src(first), second);
+  }
+
+  Dest m_dest;
+  Src m_src;
+};
+    
+template <typename Src, typename Dest>
+inline on2_t<Src, Dest>
+on2(Src s, Dest d) {
+  return on2_t<Src, Dest>(s, d);
+}  
+
 // Creates a functor for accessing a member.
 template <typename Class, typename Member>
 struct mem_ptr_t : public std::unary_function<Class*, Member&> {
@@ -462,15 +482,15 @@ public:
   typedef Ret (Object::*Function)() const;
 
   const_mem_fun0() : m_object(NULL) {}
-  const_mem_fun0(Object* o, Function f) : m_object(o), m_function(f) {}
+  const_mem_fun0(const Object* o, Function f) : m_object(o), m_function(f) {}
 
   bool is_valid() const { return m_object; }
 
-  Ret operator () () { return (m_object->*m_function)(); }
+  Ret operator () () const { return (m_object->*m_function)(); }
   
 private:
-  Object* m_object;
-  Function m_function;
+  const Object* m_object;
+  Function      m_function;
 };
 
 template <typename Object, typename Ret, typename Arg1>
@@ -498,15 +518,15 @@ public:
   typedef Ret (Object::*Function)(Arg1) const;
 
   const_mem_fun1() : m_object(NULL) {}
-  const_mem_fun1(Object* o, Function f) : m_object(o), m_function(f) {}
+  const_mem_fun1(const Object* o, Function f) : m_object(o), m_function(f) {}
 
   bool is_valid() const { return m_object; }
 
-  Ret operator () (Arg1 a1) { return (m_object->*m_function)(a1); }
+  Ret operator () (Arg1 a1) const { return (m_object->*m_function)(a1); }
   
 private:
-  Object* m_object;
-  Function m_function;
+  const Object* m_object;
+  Function      m_function;
 };
 
 template <typename Object, typename Ret, typename Arg1, typename Arg2>
@@ -557,7 +577,7 @@ make_mem_fun(Object* o, Ret (Object::*f)()) {
 
 template <typename Object, typename Ret>
 inline const_mem_fun0<Object, Ret>
-make_mem_fun(Object* o, Ret (Object::*f)() const) {
+make_mem_fun(const Object* o, Ret (Object::*f)() const) {
  return const_mem_fun0<Object, Ret>(o, f);
 }
 
@@ -569,7 +589,7 @@ make_mem_fun(Object* o, Ret (Object::*f)(Arg1)) {
 
 template <typename Object, typename Ret, typename Arg1>
 inline const_mem_fun1<Object, Ret, Arg1>
-make_mem_fun(Object* o, Ret (Object::*f)(Arg1) const) {
+make_mem_fun(const Object* o, Ret (Object::*f)(Arg1) const) {
  return const_mem_fun1<Object, Ret, Arg1>(o, f);
 }
 
