@@ -62,15 +62,14 @@ class socket_address_inet6;
 
 class socket_address {
 public:
-  static const sa_family_t af_local  = AF_LOCAL;
   static const sa_family_t af_inet   = AF_INET;
   static const sa_family_t af_inet6  = AF_INET6;
   static const sa_family_t af_unspec = AF_UNSPEC;
 
-#ifdef AF_UNIX
-  static const sa_family_t af_unix   = AF_UNIX;
+#ifdef AF_LOCAL
+  static const sa_family_t af_local  = AF_LOCAL;
 #else
-  static const sa_family_t af_unix   = AF_FILE;
+  static const sa_family_t af_local  = AF_UNIX;
 #endif
 
   bool                is_valid() const;
