@@ -168,11 +168,6 @@ ConnectionList::set_difference(AddressList* l) {
            l->end());
 }
 
-void
-ConnectionList::send_finished_chunk(uint32_t index) {
-  std::for_each(begin(), end(), std::bind2nd(std::mem_fun(&PeerConnectionBase::receive_finished_chunk), index));
-}
-
 void
 ConnectionList::set_max_size(size_type v) { 
   m_maxSize = v;
