@@ -45,10 +45,11 @@
 #include <sigc++/signal.h>
 
 #include "torrent/rate.h"
+#include "torrent/hash_string.h"
 
 namespace torrent {
 
-class Content;
+class FileList;
 class DownloadMain;
 class Rate;
 
@@ -56,7 +57,7 @@ class Rate;
 
 class DownloadInfo {
 public:
-  typedef rak::const_mem_fun0<Content, uint64_t>                       slot_stat_type;
+  typedef rak::const_mem_fun0<FileList, uint64_t>                      slot_stat_type;
 
   typedef sigc::signal1<void, const std::string&>                      signal_string_type;
   typedef sigc::signal1<void, uint32_t>                                signal_chunk_type;
@@ -80,6 +81,8 @@ public:
 
     m_upRate(60),
     m_downRate(60),
+    m_skipRate(60),
+
     m_uploadedBaseline(0),
     m_completedBaseline(0) {
   }
@@ -87,11 +90,14 @@ public:
   const std::string&  name() const                                 { return m_name; }
   void                set_name(const std::string& s)               { m_name = s; }
 
-  const std::string&  hash() const                                 { return m_hash; }
-  void                set_hash(const std::string& hash)            { m_hash = hash; }
+  const HashString&   hash() const                                 { return m_hash; }
+  HashString&         mutable_hash()                               { return m_hash; }
 
-  const std::string&  local_id() const                             { return m_localId; }
-  void                set_local_id(const std::string& id)          { m_localId = id; }
+  const HashString&   hash_obfuscated() const                      { return m_hashObfuscated; }
+  HashString&         mutable_hash_obfuscated()                    { return m_hashObfuscated; }
+
+  const HashString&   local_id() const                             { return m_localId; }
+  HashString&         mutable_local_id()                           { return m_localId; }
 
   bool                is_open() const                              { return m_isOpen; }
   void                set_open(bool s)                             { m_isOpen = s; }
@@ -113,6 +119,7 @@ public:
 
   Rate*               up_rate()                                    { return &m_upRate; }
   Rate*               down_rate()                                  { return &m_downRate; }
+  Rate*               skip_rate()                                  { return &m_skipRate; }
 
   uint64_t            uploaded_baseline() const                    { return m_uploadedBaseline; }
   void                set_uploaded_baseline(uint64_t b)            { m_uploadedBaseline = b; }
@@ -133,8 +140,9 @@ public:
 
 private:
   std::string         m_name;
-  std::string         m_hash;
-  std::string         m_localId;
+  HashString          m_hash;
+  HashString          m_hashObfuscated;
+  HashString          m_localId;
 
   bool                m_isOpen;
   bool                m_isActive;
@@ -146,6 +154,7 @@ private:
 
   Rate                m_upRate;
   Rate                m_downRate;
+  Rate                m_skipRate;
 
   uint64_t            m_uploadedBaseline;
   uint64_t            m_completedBaseline;
