@@ -67,8 +67,23 @@ DownloadMain::DownloadMain() :
   m_uploadThrottle(NULL),
   m_downloadThrottle(NULL) {
 
-  m_connectionList = new ConnectionList(this);
-  m_chokeManager = new ChokeManager(m_connectionList);
+  m_connectionList       = new ConnectionList(this);
+  m_uploadChokeManager   = new ChokeManager(m_connectionList);
+  m_downloadChokeManager = new ChokeManager(m_connectionList, ChokeManager::flag_unchoke_all_new);
+
+  m_uploadChokeManager->set_slot_choke_weight(&calculate_upload_choke);
+  m_uploadChokeManager->set_slot_unchoke_weight(&calculate_upload_unchoke);
+  m_uploadChokeManager->set_slot_connection(std::mem_fun(&PeerConnectionBase::receive_upload_choke));
+
+  std::memcpy(m_uploadChokeManager->choke_weight(),   weights_upload_choke,   ChokeManager::weight_size_bytes);
+  std::memcpy(m_uploadChokeManager->unchoke_weight(), weights_upload_unchoke, ChokeManager::weight_size_bytes);
+
+  m_downloadChokeManager->set_slot_choke_weight(&calculate_download_choke);
+  m_downloadChokeManager->set_slot_unchoke_weight(&calculate_download_unchoke);
+  m_downloadChokeManager->set_slot_connection(std::mem_fun(&PeerConnectionBase::receive_download_choke));
+
+  std::memcpy(m_downloadChokeManager->choke_weight(),   weights_download_choke,   ChokeManager::weight_size_bytes);
+  std::memcpy(m_downloadChokeManager->unchoke_weight(), weights_download_unchoke, ChokeManager::weight_size_bytes);
 
   m_delegator.slot_chunk_find(rak::make_mem_fun(m_chunkSelector, &ChunkSelector::find));
   m_delegator.slot_chunk_size(rak::make_mem_fun(file_list(), &FileList::chunk_index_size));
@@ -89,7 +104,8 @@ DownloadMain::~DownloadMain() {
     throw internal_error("DownloadMain::~DownloadMain(): m_taskTrackerRequest is queued.");
 
   delete m_trackerManager;
-  delete m_chokeManager;
+  delete m_uploadChokeManager;
+  delete m_downloadChokeManager;
   delete m_connectionList;
 
   delete m_chunkStatistics;
@@ -121,7 +137,10 @@ DownloadMain::close() {
 
   info()->set_open(false);
 
-  m_trackerManager->close();
+  // Don't close the tracker manager here else it will cause STOPPED
+  // requests to be lost. TODO: Check that this is valid.
+//   m_trackerManager->close();
+
   m_delegator.transfer_list()->clear();
 
   file_list()->mutable_bitfield()->unallocate();
