@@ -76,8 +76,8 @@ public:
   void                start();
   void                stop();
 
-  ChokeManager*       choke_manager()                            { return m_chokeManager; }
-  TrackerManager*     tracker_manager()                          { return m_trackerManager; }
+  ChokeManager*       upload_choke_manager()                     { return m_uploadChokeManager; }
+  ChokeManager*       download_choke_manager()                   { return m_downloadChokeManager; }
   TrackerManager*     tracker_manager() const                    { return m_trackerManager; }
 
   DownloadInfo*       info()                                     { return m_info; }
@@ -136,7 +136,8 @@ private:
   DownloadInfo*       m_info;
 
   TrackerManager*     m_trackerManager;
-  ChokeManager*       m_chokeManager;
+  ChokeManager*       m_uploadChokeManager;
+  ChokeManager*       m_downloadChokeManager;
 
   ChunkList*          m_chunkList;
   ChunkSelector*      m_chunkSelector;
