@@ -42,7 +42,7 @@
 #include <sigc++/signal.h>
 
 #include "data/chunk_handle.h"
-#include "torrent/peer.h"
+#include "torrent/peer/peer.h"
 #include "download/download_info.h"
 
 #include "download_main.h"
@@ -81,20 +81,27 @@ public:
 
   DownloadMain*       main()                                  { return &m_main; }
   const DownloadMain* main() const                            { return &m_main; }
-  HashTorrent*        hash_checker()                          { return m_hash; }
+  HashTorrent*        hash_checker()                          { return m_hashChecker; }
 
   Object*             bencode()                               { return m_bencode; }
   void                set_bencode(Object* o)                  { m_bencode = o; }
 
+  HashQueue*          hash_queue()                            { return m_hashQueue; }
+  void                set_hash_queue(HashQueue* q)            { m_hashQueue = q; }
+
+  const std::string&  complete_hash()                            { return m_hash; }
+  const char*         chunk_hash(unsigned int index)             { return m_hash.c_str() + 20 * index; }
+  void                set_complete_hash(const std::string& hash) { m_hash = hash; }
+
   DownloadInfo*       info()                                  { return m_main.info(); }
 
   int                 connection_type() const                 { return m_connectionType; }
   void                set_connection_type(int t)              { m_connectionType = t; }
 
   void                receive_initial_hash();
+  void                receive_hash_done(ChunkHandle handle, const char* hash);
 
   void                check_chunk_hash(ChunkHandle handle);
-  void                receive_hash_done(ChunkHandle handle, const char* hash);
 
   void                receive_storage_error(const std::string& str);
   void                receive_tracker_success(AddressList* l);
@@ -128,7 +135,10 @@ private:
 
   DownloadMain        m_main;
   Object*             m_bencode;
-  HashTorrent*        m_hash;
+  HashTorrent*        m_hashChecker;
+  HashQueue*          m_hashQueue;
+
+  std::string         m_hash;
 
   int                 m_connectionType;
 
