@@ -36,7 +36,7 @@
 
 #include "config.h"
 
-#include <sstream>
+#include <cstdio>
 #include <rak/error_number.h>
 
 #include "torrent/exceptions.h"
@@ -69,8 +69,12 @@ PeerConnectionBase::PeerConnectionBase() :
 
   m_downStall(0),
 
+  m_downInterested(false),
+  m_downUnchoked(false),
+
   m_sendChoked(false),
   m_sendInterested(false),
+  m_tryRequest(true),
 
   m_encryptBuffer(NULL) {
 }
@@ -122,7 +126,14 @@ PeerConnectionBase::initialize(DownloadMain* download, PeerInfo* peerInfo, Socke
   m_download->chunk_statistics()->received_connect(&m_peerChunks);
 
   // Hmm... cleanup?
-  update_interested();
+//   update_interested();
+
+  m_peerChunks.download_cache()->clear();
+
+  if (!m_download->file_list()->is_done()) {
+    m_sendInterested = true;
+    m_downInterested = true;
+  }
 
   initialize_custom();
 }
@@ -140,7 +151,8 @@ PeerConnectionBase::cleanup() {
   up_chunk_release();
   down_chunk_release();
 
-  m_download->choke_manager()->disconnected(this);
+  m_download->upload_choke_manager()->disconnected(this, &m_upChoke);
+  m_download->download_choke_manager()->disconnected(this, &m_downChoke);
   m_download->chunk_statistics()->received_disconnect(&m_peerChunks);
 
   manager->poll()->remove_read(this);
@@ -162,6 +174,88 @@ PeerConnectionBase::cleanup() {
   m_download = NULL;
 }
 
+void
+PeerConnectionBase::set_upload_snubbed(bool v) {
+  if (v)
+    m_download->upload_choke_manager()->set_snubbed(this, &m_upChoke);
+  else
+    m_download->upload_choke_manager()->set_not_snubbed(this, &m_upChoke);
+}
+
+bool
+PeerConnectionBase::receive_upload_choke(bool choke) {
+  if (choke == m_upChoke.choked())
+    throw internal_error("PeerConnectionBase::receive_upload_choke(...) already set to the same state.");
+
+  write_insert_poll_safe();
+
+  m_sendChoked = true;
+  m_upChoke.set_unchoked(!choke);
+  m_upChoke.set_time_last_choke(cachedTime);
+
+  return true;
+}
+
+bool
+PeerConnectionBase::receive_download_choke(bool choke) {
+  if (choke == m_downChoke.choked())
+    throw internal_error("PeerConnectionBase::receive_download_choke(...) already set to the same state.");
+
+  write_insert_poll_safe();
+
+  m_downChoke.set_unchoked(!choke);
+  m_downChoke.set_time_last_choke(cachedTime);
+
+  if (choke) {
+    m_peerChunks.download_cache()->disable();
+
+    // If the queue isn't empty, then we might still receive some
+    // pieces, so don't remove us from throttle.
+    if (!download_queue()->is_downloading() && download_queue()->empty())
+      m_download->download_throttle()->erase(m_peerChunks.download_throttle());
+
+    // Send uninterested if unchoked, but only _after_ receiving our
+    // chunks?
+
+    if (m_downUnchoked) {
+      // Tell the peer we're no longer interested to avoid
+      // disconnects. We keep the connection in the queue so that
+      // ChokeManager::cycle(...) can attempt to get us unchoked
+      // again.
+
+      m_sendInterested = m_downInterested;
+      m_downInterested = false;
+
+    } else {
+      // Remove from queue so that an unchoke from the remote peer
+      // will cause the connection to be unchoked immediately by the
+      // choke manager.
+      m_downChoke.set_queued(false);
+      return false;
+    }
+
+  } else {
+    m_tryRequest = true;
+
+    if (!m_downInterested) {
+      // We were marked as not interested by the cycling choke and
+      // kept in the queue, thus the peer should have some pieces of
+      // interest.
+      //
+      // We have now been 'unchoked' by the choke manager, so tell the
+      // peer that we're again interested. If the peer doesn't unchoke
+      // us within a cycle or two we're likely to be choked and left
+      // out of the queue. So if the peer unchokes us at a later time,
+      // we skip the queue and unchoke immediately.
+
+      m_sendInterested = !m_downInterested;
+      m_downInterested = true;
+    }
+  }
+
+  return true;
+}
+
 void
 PeerConnectionBase::load_up_chunk() {
   if (m_upChunk.is_valid() && m_upChunk.index() == m_upPiece.index()) {
@@ -202,36 +296,6 @@ PeerConnectionBase::load_up_chunk() {
   m_upChunk.chunk()->preload(m_upPiece.offset(), m_upChunk.chunk()->chunk_size(), cm->preload_type() == 1);
 }
 
-void
-PeerConnectionBase::set_snubbed(bool v) {
-  if (v == m_peerChunks.is_snubbed())
-    return;
-
-  bool wasUploadWanted = is_upload_wanted();
-  m_peerChunks.set_snubbed(v);
-
-  if (v) {
-    if (wasUploadWanted)
-      m_download->choke_manager()->set_not_interested(this);
-
-  } else {
-    if (is_upload_wanted())
-      m_download->choke_manager()->set_interested(this);
-  }
-}
-
-void
-PeerConnectionBase::receive_choke(bool v) {
-  if (v == m_up->choked())
-    throw internal_error("PeerConnectionBase::receive_choke(...) already set to the same state.");
-
-  write_insert_poll_safe();
-
-  m_sendChoked = true;
-  m_up->set_choked(v);
-  m_timeLastChoked = cachedTime;
-}
-
 void
 PeerConnectionBase::cancel_transfer(BlockTransfer* transfer) {
   if (!get_fd().is_valid())
@@ -306,7 +370,12 @@ PeerConnectionBase::down_chunk_finished() {
     m_downStall--;
         
   // TODO: clear m_down.data?
-  // TODO: remove throttle if choked? Rarely happens though.
+
+  // If we were choked by choke_manager but still had queued pieces,
+  // then we might still be in the throttle.
+  if (m_downChoke.choked() && download_queue()->empty())
+    m_download->download_throttle()->erase(m_peerChunks.download_throttle());
+
   write_insert_poll_safe();
 }
 
@@ -565,7 +634,7 @@ void
 PeerConnectionBase::read_request_piece(const Piece& p) {
   PeerChunks::piece_list_type::iterator itr = std::find(m_peerChunks.upload_queue()->begin(), m_peerChunks.upload_queue()->end(), p);
   
-  if (m_up->choked() || itr != m_peerChunks.upload_queue()->end() || p.length() > (1 << 17))
+  if (m_upChoke.choked() || itr != m_peerChunks.upload_queue()->end() || p.length() > (1 << 17))
     return;
 
   m_peerChunks.upload_queue()->push_back(p);
@@ -588,17 +657,12 @@ PeerConnectionBase::write_prepare_piece() {
   // Move these checks somewhere else?
   if (!m_download->file_list()->is_valid_piece(m_upPiece) ||
       !m_download->file_list()->bitfield()->get(m_upPiece.index())) {
-    std::stringstream s;
+    char buffer[128];
+    snprintf(buffer, 128, "Peer requested an invalid piece: %u %u %u", m_upPiece.index(), m_upPiece.length(), m_upPiece.offset());
 
-    s << "Peer requested a piece with invalid index or length/offset: "
-      << m_upPiece.index() << ' '
-      << m_upPiece.length() << ' '
-      << m_upPiece.offset();
-
-    throw communication_error(s.str());
-//     throw communication_error("Peer requested a piece with invalid index or length/offset.");
+    throw communication_error(buffer);
   }
-      
+  
   m_up->write_piece(m_upPiece);
 }
 
@@ -607,7 +671,7 @@ PeerConnectionBase::write_prepare_piece() {
 // from high stall counts when we are doing decent speeds.
 bool
 PeerConnectionBase::should_request() {
-  if (m_down->choked() || !m_up->interested())
+  if (m_downChoke.choked() || !m_downInterested || !m_downUnchoked)
     // || m_down->get_state() == ProtocolRead::READ_SKIP_PIECE)
     return false;
 
@@ -657,28 +721,4 @@ PeerConnectionBase::try_request_pieces() {
   return success;
 }
 
-void
-PeerConnectionBase::set_remote_interested() {
-  if (m_down->interested() || m_peerChunks.bitfield()->is_all_set())
-    return;
-
-  m_down->set_interested(true);
-
-  if (is_upload_wanted())
-    m_download->choke_manager()->set_interested(this);
-}
-
-void
-PeerConnectionBase::set_remote_not_interested() {
-  if (!m_down->interested())
-    return;
-
-  bool wasUploadWanted = is_upload_wanted();
-
-  m_down->set_interested(false);
-
-  if (wasUploadWanted)
-    m_download->choke_manager()->set_not_interested(this);
-}
-
 }
