@@ -38,6 +38,7 @@
 #define LIBTORRENT_PROTOCOL_PEER_CONNECTION_BASE_H
 
 #include "data/chunk_handle.h"
+#include "download/choke_manager_node.h"
 #include "net/socket_stream.h"
 #include "torrent/poll.h"
 
@@ -82,12 +83,16 @@ public:
   void                initialize(DownloadMain* download, PeerInfo* p, SocketFd fd, Bitfield* bitfield, EncryptionInfo* encryptionInfo);
   void                cleanup();
 
-  bool                is_up_choked()                { return m_up->choked(); }
-  bool                is_up_interested()            { return m_up->interested(); }
-  bool                is_down_choked()              { return m_down->choked(); }
-  bool                is_down_interested()          { return m_down->interested(); }
+  bool                is_up_choked()                { return m_upChoke.choked(); }
+  bool                is_up_interested()            { return m_upChoke.queued(); }
+  bool                is_up_snubbed()               { return m_upChoke.snubbed(); }
 
-  bool                is_upload_wanted() const      { return m_down->interested() && !m_peerChunks.is_snubbed(); }
+  bool                is_down_queued()              { return m_downChoke.queued(); }
+  bool                is_down_local_unchoked()      { return m_downChoke.unchoked(); }
+  bool                is_down_remote_unchoked()     { return m_downUnchoked; }
+  bool                is_down_interested()          { return m_downInterested; }
+
+  void                set_upload_snubbed(bool v);
 
   bool                is_seeder() const             { return m_peerChunks.is_seeder(); }
 
@@ -98,22 +103,16 @@ public:
   const PeerInfo*     c_peer_info() const           { return m_peerInfo; }
   PeerChunks*         peer_chunks()                 { return &m_peerChunks; }
 
+  DownloadMain*       download()                    { return m_download; }
   RequestList*        download_queue()              { return &m_downloadQueue; }
 
-  // Make sure you choke the peer when snubbing. Snubbing a peer will
-  // only cause it not to be unchoked.
-  //
-  // Move this stuff to PeerChunks.
-  void                set_snubbed(bool v);
-
-  rak::timer          time_last_choked() const      { return m_timeLastChoked; }
-
   // These must be implemented by the child class.
   virtual void        initialize_custom() = 0;
   virtual void        update_interested() = 0;
   virtual bool        receive_keepalive() = 0;
 
-  void                receive_choke(bool v);
+  bool                receive_upload_choke(bool choke);
+  bool                receive_download_choke(bool choke);
 
   virtual void        event_error();
 
@@ -155,9 +154,6 @@ protected:
   bool                should_request();
   bool                try_request_pieces();
 
-  void                set_remote_interested();
-  void                set_remote_not_interested();
-
   // Insert into the poll unless we're blocking for throttling etc.
   void                read_insert_poll_safe();
   void                write_insert_poll_safe();
@@ -177,10 +173,26 @@ protected:
   Piece               m_upPiece;
   ChunkHandle         m_upChunk;
 
+  // The interested state no longer follows the spec's wording as it
+  // has been swapped.
+  //
+  // Thus the same ProtocolBase object now groups the same choke and
+  // interested states togheter, thus for m_up 'interested' means the
+  // remote peer wants upload and 'choke' means we've choked upload to
+  // that peer.
+  //
+  // In the downlod object, 'queued' now means the same as the spec's
+  // 'unchoked', while 'unchoked' means we start requesting pieces.
+  ChokeManagerNode    m_upChoke;
+  ChokeManagerNode    m_downChoke;
+
+  bool                m_downInterested;
+  bool                m_downUnchoked;
+
   bool                m_sendChoked;
   bool                m_sendInterested;
+  bool                m_tryRequest;
 
-  rak::timer          m_timeLastChoked;
   rak::timer          m_timeLastRead;
 
   EncryptBuffer*      m_encryptBuffer;
