@@ -40,6 +40,7 @@
 #include <sstream>
 
 #include "data/chunk_list_node.h"
+#include "download/choke_manager.h"
 #include "download/chunk_selector.h"
 #include "download/chunk_statistics.h"
 #include "download/download_info.h"
@@ -69,21 +70,21 @@ PeerConnectionLeech::initialize_custom() {
 
 void
 PeerConnectionLeech::update_interested() {
-// FIXME:   if (m_download->delegator()->get_select().interested(m_peerChunks.bitfield()->bitfield())) {
+  m_peerChunks.download_cache()->clear();
+
+  if (m_downInterested)
+    return;
 
   // Consider just setting to interested without checking the
   // bitfield. The status might change by the time we get unchoked
   // anyway.
 
-  if (true) {
-    m_sendInterested = !m_up->interested();
-    m_up->set_interested(true);
-  } else {
-    m_sendInterested = m_up->interested();
-    m_up->set_interested(false);
-  }
+  m_sendInterested = !m_downInterested;
+  m_downInterested = true;
 
-  m_peerChunks.download_cache()->clear();
+  // Hmm... does this belong here, or should we insert ourselves into
+  // the queue when we receive the unchoke?
+//   m_download->download_choke_manager()->set_queued(this, &m_downChoke);
 }
 
 bool
@@ -100,6 +101,7 @@ PeerConnectionLeech::receive_keepalive() {
 
     ProtocolBuffer<512>::iterator old_end = m_up->buffer()->end();
     m_up->write_keepalive();
+
     if (is_encrypted())
       m_encryption.encrypt(old_end, m_up->buffer()->end() - old_end);
   }
@@ -113,6 +115,9 @@ PeerConnectionLeech::receive_keepalive() {
   // should stay at zero or one when downloading at an acceptable
   // speed. Thus only when m_downStall >= 2 is the download actually
   // stalling.
+
+  // TODO: Do we need to remove from download throttle here?
+
   if (!download_queue()->empty() && m_downStall++ != 0)
     download_queue()->stall();
 
@@ -155,7 +160,7 @@ PeerConnectionLeech::read_message() {
   // the above test.
   //
   // Those that do in some weird way manage to produce a valid
-  // command, will not be able to do any damage as malicious
+  // command, will not be able to do any more damage than a malicious
   // peer. Those cases should be caught elsewhere in the code.
 
   // Temporary.
@@ -163,31 +168,42 @@ PeerConnectionLeech::read_message() {
 
   switch (buf->read_8()) {
   case ProtocolBase::CHOKE:
-    m_down->set_choked(true);
+    // Cancel before dequeueing so receive_download_choke knows if it
+    // should remove us from throttle.
+    //
+    // Hmm... that won't work, as we arn't necessarily unchoked when
+    // in throttle.
 
-    m_peerChunks.download_cache()->disable();
+    // Which needs to be done before, and which after calling choke
+    // manager?
+    m_downUnchoked = false;
 
     download_queue()->cancel();
+    m_download->download_choke_manager()->set_not_queued(this, &m_downChoke);
     m_download->download_throttle()->erase(m_peerChunks.download_throttle());
 
     return true;
 
   case ProtocolBase::UNCHOKE:
-    if (is_down_choked()) {
-      write_insert_poll_safe();
+    m_downUnchoked = true;
 
-      m_down->set_choked(false);
-      m_tryRequest = true;
-    }
+    // Some peers unchoke us even though we're not interested, so we
+    // need to ensure it doesn't get added to the queue.
+    if (!m_downInterested)
+      return true;
 
+    m_download->download_choke_manager()->set_queued(this, &m_downChoke);
     return true;
 
   case ProtocolBase::INTERESTED:
-    set_remote_interested();
+    if (m_peerChunks.bitfield()->is_all_set())
+      return true;
+
+    m_download->upload_choke_manager()->set_queued(this, &m_upChoke);
     return true;
 
   case ProtocolBase::NOT_INTERESTED:
-    set_remote_not_interested();
+    m_download->upload_choke_manager()->set_not_queued(this, &m_upChoke);
     return true;
 
   case ProtocolBase::HAVE:
@@ -201,7 +217,7 @@ PeerConnectionLeech::read_message() {
     if (!m_down->can_read_request_body())
       break;
 
-    if (!m_up->choked()) {
+    if (!m_upChoke.choked()) {
       write_insert_poll_safe();
       read_request_piece(m_down->read_request());
 
@@ -373,9 +389,9 @@ PeerConnectionLeech::fill_write_buffer() {
   // No need to use delayed choke as we are a leecher.
   if (m_sendChoked && m_up->can_write_choke()) {
     m_sendChoked = false;
-    m_up->write_choke(m_up->choked());
+    m_up->write_choke(m_upChoke.choked());
 
-    if (m_up->choked()) {
+    if (m_upChoke.choked()) {
       m_download->upload_throttle()->erase(m_peerChunks.upload_throttle());
       up_chunk_release();
       m_peerChunks.upload_queue()->clear();
@@ -398,18 +414,20 @@ PeerConnectionLeech::fill_write_buffer() {
   // request has been received while uninterested. The problem arises
   // as they send unchoke before receiving interested.
   if (m_sendInterested && m_up->can_write_interested()) {
-    m_up->write_interested(m_up->interested());
+    m_up->write_interested(m_downInterested);
     m_sendInterested = false;
   }
 
-  if (m_tryRequest &&
+  if (m_tryRequest) {
+    if (!(m_tryRequest = !should_request()) &&
+        !(m_tryRequest = try_request_pieces()) &&
 
-      !(m_tryRequest = !should_request()) &&
-      !(m_tryRequest = try_request_pieces()) &&
+        !download_queue()->is_interested_in_active()) {
+      m_sendInterested = true;
+      m_downInterested = false;
 
-      !download_queue()->is_interested_in_active()) {
-    m_sendInterested = true;
-    m_up->set_interested(false);
+      m_download->download_choke_manager()->set_not_queued(this, &m_downChoke);
+    }
   }
 
   DownloadMain::have_queue_type* haveQueue = m_download->have_queue();
@@ -432,7 +450,7 @@ PeerConnectionLeech::fill_write_buffer() {
     m_peerChunks.cancel_queue()->pop_front();
   }
 
-  if (!m_up->choked() &&
+  if (!m_upChoke.choked() &&
       !m_peerChunks.upload_queue()->empty() &&
       m_up->can_write_piece())
     write_prepare_piece();
@@ -524,16 +542,17 @@ PeerConnectionLeech::read_have_chunk(uint32_t index) {
 
   m_download->chunk_statistics()->received_have_chunk(&m_peerChunks, index, m_download->file_list()->chunk_size());
 
-  if (m_peerChunks.bitfield()->is_all_set())
+  if (m_peerChunks.bitfield()->is_all_set()) {
     if (m_download->file_list()->is_done())
       throw close_connection();
-    else
-      set_remote_not_interested();
+
+    m_download->upload_choke_manager()->set_not_queued(this, &m_upChoke);
+  }
 
   if (m_download->file_list()->is_done())
     return;
 
-  if (is_up_interested()) {
+  if (is_down_interested()) {
 
     if (!m_tryRequest && m_download->chunk_selector()->received_have_chunk(&m_peerChunks, index)) {
       m_tryRequest = true;
@@ -543,9 +562,15 @@ PeerConnectionLeech::read_have_chunk(uint32_t index) {
   } else {
 
     if (m_download->chunk_selector()->received_have_chunk(&m_peerChunks, index)) {
-      m_sendInterested = true;
-      m_up->set_interested(true);
+      m_sendInterested = !m_downInterested;
+      m_downInterested = true;
       
+      // Ensure we get inserted into the chunk manager queue in case
+      // the peer keeps us unchoked even though we've said we're not
+      // interested.
+      if (m_downUnchoked)
+        m_download->download_choke_manager()->set_queued(this, &m_downChoke);
+
       // Is it enough to insert into write here? Make the interested
       // check branch to include insert_write, even when not sending
       // interested.
