@@ -39,6 +39,7 @@
 #include <cstring>
 #include <sstream>
 
+#include "download/choke_manager.h"
 #include "download/chunk_statistics.h"
 #include "download/download_info.h"
 #include "download/download_main.h"
@@ -131,19 +132,15 @@ PeerConnectionSeed::read_message() {
 
   switch (buf->read_8()) {
   case ProtocolBase::CHOKE:
-    m_down->set_choked(true);
-    return true;
-
   case ProtocolBase::UNCHOKE:
-    m_down->set_choked(false);
     return true;
 
   case ProtocolBase::INTERESTED:
-    set_remote_interested();
+    m_download->upload_choke_manager()->set_queued(this, &m_upChoke);
     return true;
 
   case ProtocolBase::NOT_INTERESTED:
-    set_remote_not_interested();
+    m_download->upload_choke_manager()->set_not_queued(this, &m_upChoke);
     return true;
 
   case ProtocolBase::HAVE:
@@ -157,7 +154,7 @@ PeerConnectionSeed::read_message() {
     if (!m_down->can_read_request_body())
       break;
 
-    if (!m_up->choked()) {
+    if (!m_upChoke.choked()) {
       write_insert_poll_safe();
       read_request_piece(m_down->read_request());
 
@@ -256,9 +253,9 @@ PeerConnectionSeed::fill_write_buffer() {
   // No need to use delayed choke as we are a seeder.
   if (m_sendChoked && m_up->can_write_choke()) {
     m_sendChoked = false;
-    m_up->write_choke(m_up->choked());
+    m_up->write_choke(m_upChoke.choked());
 
-    if (m_up->choked()) {
+    if (m_upChoke.choked()) {
       m_download->upload_throttle()->erase(m_peerChunks.upload_throttle());
       up_chunk_release();
       m_peerChunks.upload_queue()->clear();
@@ -268,7 +265,7 @@ PeerConnectionSeed::fill_write_buffer() {
     }
   }
 
-  if (!m_up->choked() &&
+  if (!m_upChoke.choked() &&
       !m_peerChunks.upload_queue()->empty() &&
       m_up->can_write_piece())
     write_prepare_piece();
