@@ -37,6 +37,8 @@
 #ifndef LIBTORRENT_NET_PROTOCOL_BASE_H
 #define LIBTORRENT_NET_PROTOCOL_BASE_H
 
+#include <rak/timer.h>
+
 #include "net/protocol_buffer.h"
 
 namespace torrent {
@@ -74,20 +76,12 @@ public:
   } State;
 
   ProtocolBase() :
-    m_choked(true),
-    m_interested(false),
     m_state(IDLE),
     m_lastCommand(NONE) {
 
     m_buffer.reset();
   }
 
-  bool                choked() const                          { return m_choked; }
-  void                set_choked(bool s)                      { m_choked = s; }
-
-  bool                interested() const                      { return m_interested; }
-  void                set_interested(bool s)                  { m_interested = s; }
-
   Protocol            last_command() const                    { return m_lastCommand; }
   void                set_last_command(Protocol p)            { m_lastCommand = p; }
 
@@ -138,9 +132,6 @@ public:
   bool                can_read_piece_body() const             { return m_buffer.remaining() >= sizeof_piece_body; }
 
 protected:
-  bool                m_choked;
-  bool                m_interested;
-
   State               m_state;
   Protocol            m_lastCommand;
 
