@@ -358,7 +358,10 @@ FileList::open() {
 
       // Update the path during open so that any changes to root dir
       // and file paths are properly handled.
-      entry->set_frozen_path(m_rootDir + entry->path()->as_string());
+      if (entry->path()->back().empty())
+        entry->set_frozen_path(std::string());
+      else
+        entry->set_frozen_path(m_rootDir + entry->path()->as_string());
 
       if (!pathSet.insert(entry->frozen_path().c_str()).second)
         throw storage_error("Found a duplicate filename.");
@@ -393,7 +396,9 @@ FileList::close() {
   for (iterator itr = begin(), last = end(); itr != last; ++itr) {
     manager->file_manager()->close(*itr);
     
-    (*itr)->set_completed(0);
+    // Keep the progress so the user can see it even though he closes
+    // the torrent.
+//     (*itr)->set_completed(0);
   }
 
   m_isOpen = false;
@@ -402,14 +407,14 @@ FileList::close() {
 
 bool
 FileList::resize_all() {
-  iterator itr = std::find_if(begin(), end(), std::not1(std::mem_fun(&File::resize_file)));
+  bool success = true;
 
-  if (itr != end()) {
-    std::for_each(++itr, end(), std::mem_fun(&File::resize_file));
-    return false;
-  }
+  for (iterator itr = begin(); itr != end(); itr++)
+    if (!(*itr)->frozen_path().empty() &&
+        !(*itr)->resize_file())
+      success = false;
 
-  return true;
+  return success;
 }
 
 void
@@ -570,11 +575,25 @@ FileList::update_completed() {
   if (!m_bitfield.is_tail_cleared())
     throw internal_error("Content::update_done() called but m_bitfield's tail isn't cleared.");
 
-  iterator entryItr = begin();
+  if (m_bitfield.is_all_set()) {
+    for (iterator itr = begin(), last = end(); itr != last; ++itr)
+      (*itr)->set_completed((*itr)->size_chunks());
 
-  for (Bitfield::size_type index = 0; index < m_bitfield.size_bits(); ++index)
-    if (m_bitfield.get(index))
-      entryItr = inc_completed(entryItr, index);
+  } else {
+    // Clear any old progress data from the entries as we don't clear
+    // this on close, etc.
+    for (iterator itr = begin(), last = end(); itr != last; ++itr)
+      (*itr)->set_completed(0);
+
+    if (m_bitfield.is_all_unset())
+      return;
+
+    iterator entryItr = begin();
+
+    for (Bitfield::size_type index = 0; index < m_bitfield.size_bits(); ++index)
+      if (m_bitfield.get(index))
+        entryItr = inc_completed(entryItr, index);
+  }
 }
 
 void
