@@ -39,8 +39,8 @@
 
 #include <string>
 #include <iosfwd>
-#include <inttypes.h>
 #include <sigc++/signal.h>
+#include <torrent/common.h>
 
 namespace torrent {
 
@@ -48,7 +48,7 @@ namespace torrent {
 // "CLIENT_NAME/CLIENT_VERSION/LIBRARY_VERSION".
 
 // Keep in mind that these objects get reused.
-class Http {
+class LIBTORRENT_EXPORT Http {
  public:
   typedef sigc::signal0<void>                     Signal;
   typedef sigc::signal1<void, const std::string&> SignalString;
@@ -72,13 +72,16 @@ class Http {
   uint32_t           timeout() const                      { return m_timeout; }
   void               set_timeout(uint32_t seconds)        { m_timeout = seconds; }
 
+  // The owner of the Http object must close it as soon as possible
+  // after receiving the signal, as the implementation may allocate
+  // limited resources during its lifetime.
   Signal&            signal_done()                        { return m_signalDone; }
   SignalString&      signal_failed()                      { return m_signalFailed; }
 
   // Set the factory function that constructs and returns a valid Http* object.
   static void        set_factory(const SlotFactory& f);
 
-  // Guaranteed to return a valid object or throw a client_error. The
+  // Guaranteed to return a valid object or throw a internal_error. The
   // caller takes ownership of the returned object. Is there any
   // interest in making a destructor slot?
   static Http*       call_factory();
